@@ -1,5 +1,6 @@
 import urllib, urllib2
 import json as json
+import hashlib
 
 #
 # REAKTOR
@@ -14,11 +15,10 @@ class Reaktor:
 
 		# login to reaktor.io
 		self.__api = "http://api.reaktor.io/"
-
 		
 		d = {
 			"mail": mail, 
-			"pass": password
+			"pass": hashlib.md5(password).hexdigest()
 		}
 
 		# create POST request to login
@@ -29,8 +29,6 @@ class Reaktor:
 
 		# validate result of login
 		if bool(res["ok"]) == True:
-
-			print "logged in"
 			self.__token = res["token"]
 
 		else:
