@@ -6,9 +6,9 @@ reaktor = Reaktor("test@test.de", "test")
 
 # trigger "Test" event
 d = {
-	"name": "Thomas"
+	"test": "Thomas"
 }
-ok = reaktor.trigger("Test", data=d, safe=True)
+ok = reaktor.trigger("Test", data=d, safe=False)
 
 # print result
 print "event triggered: " + str(ok)
\ No newline at end of file
